aws_with
========

aws_with is a command line utility to help manage large and complex AWS environments.

It can run the same command across a number of AWS regions, accounts and can traverse AWS Organizations.

To get started::

    sudo pip install aws_with
    aws_with --help


